@@ -49,6 +49,16 @@ export class PaymentPage {
 
     }
 
+    updateSubscriptionInfo() {
+        delete this.app.subscription
+        activateWait()
+        // Wait five seconds, then reload subscription status
+        setTimeout(() => {
+            deactivateWait()
+            this.init()
+        }, 5000)
+    }
+
     handleClick(duration) {
         if (this.app.subscription.subscribed && !this.app.subscription.subscription_end) {
             if (this.app.subscription.subscribed === duration) {
@@ -62,7 +72,7 @@ export class PaymentPage {
                             classes: "fw-dark",
                             click: () => window.Paddle.Checkout.open({
                                 override: this.app.subscription.update_url,
-                                success: window.location.href
+                                successCallback: () => this.updateSubscriptionInfo()
                             })
                         },
                         {
@@ -70,7 +80,7 @@ export class PaymentPage {
                             classes: "fw-dark",
                             click: () => window.Paddle.Checkout.open({
                                 override: this.app.subscription.cancel_url,
-                                success: window.location.href
+                                successCallback: () => this.updateSubscriptionInfo()
                             })
                         },
                         {
@@ -97,20 +107,12 @@ export class PaymentPage {
                             text: gettext("Yes"),
                             classes: "fw-dark",
                             click: () => post(
-                                "/proxy/payment/update_subscription",
+                                "/api/payment/update_subscription/",
                                 {
                                     plan_id: this.app.paddleInfo[duration].id,
                                 }
                             ).then(
-                                () => {
-                                    delete this.app.subscription
-                                    activateWait()
-                                    // Wait five seconds, then reload subscription status
-                                    setTimeout(() => {
-                                        deactivateWait()
-                                        this.init()
-                                    }, 5000)
-                                }
+                                () => this.updateSubscriptionInfo()
                             )
                         },
                         {
@@ -129,7 +131,7 @@ export class PaymentPage {
                 email: this.user.emails.find(email => email.primary).address,
                 allowQuantity: false,
                 passthrough: String(this.user.id),
-                success: window.location.href
+                successCallback: () => this.updateSubscriptionInfo()
             })
         }
     }
